@@ -6,5 +6,5 @@ register = template.Library()
 @register.inclusion_tag('sessionidletimeout/js.html', takes_context=True)
 def session_keep_alive(context):
     return context.update({
-        'interval': int(getattr(settings, 'SESSION_IDLE_TIMEOUT', 1800)) / 2 * 1000,
+        'session-keepalive-interval': int(getattr(settings, 'SESSION_IDLE_TIMEOUT', 1800)) / 2 * 1000,
     })
